@@ -217,6 +217,11 @@ def comb_recall(
         err = ae
     elif error == 're':
         err = re
+    if len(hist_achieved) == 1:
+        return float(err(achieved, desired) < tolerance) * a \
+            - float(
+                err(hist_achieved[-1], hist_desired[-1]) >= -float('inf')
+                ) * b
     return float(err(achieved, desired) < tolerance) * a \
         - float(
             err(hist_achieved[-1], hist_desired[-1]) >= err(hist_achieved[-2], hist_desired[-2])
@@ -311,7 +316,6 @@ class CRN(Physics):
         delta = sampling_rate / self.n_sub_timesteps
         t_eval = np.arange(0, sampling_rate + delta, delta)
         if self.system_noise == 0.0:
-            print("'scipy.integrate.solve_ivp' is using")
             sol = integrate.solve_ivp(
                 self.dynamics,
                 (0, sampling_rate),
@@ -367,7 +371,7 @@ class Track(Task):
         self.observability = observability
         if reward == 'comb_recall':
             reward_kwargs['hist_achieved'] = self._observations
-            reward_kwargs['hist_desireed'] = self._references
+            reward_kwargs['hist_desired'] = self._references
         self.reward_func = reward if callable(reward) else self.reward_registry[reward]
         self.reward_kwargs = reward_kwargs
         self.reward_info = reward_info
